@@ -3,7 +3,7 @@ import json
 import requests
 from hashlib import md5
 
-from dataflows import Flow, load, dump_to_path
+from dataflows import Flow, load, dump_to_path, stream, unstream
 from dataflows.base.schema_validator import ignore
 
 from ...core import BaseDataGenusProcessor, Required, Validator, ConfigurableDGP
@@ -42,6 +42,7 @@ class LoaderDGP(BaseDataGenusProcessor):
                           name=RESOURCE_NAME,
                           **source, **structure_params,
                           http_session=http_session,
+                          http_timeout=120,
                           infer_strategy=load.INFER_PYTHON_TYPES,
                           cast_strategy=load.CAST_DO_NOTHING,
                           limit_rows=(
@@ -55,16 +56,17 @@ class LoaderDGP(BaseDataGenusProcessor):
                     loader,
                 )
             else:
-                if not os.path.exists(datapackage_path):
+                if not os.path.exists(cache_path):
                     logger.info('Caching source data into %s', cache_path)
                     Flow(
                         loader,
-                        dump_to_path(cache_path, validator_options=dict(on_error=ignore)),
+                        stream(cache_path),
                         # printer(),
                     ).process()
                 logger.info('Using cached source data from %s', cache_path)
                 return Flow(
-                    load(datapackage_path, resources=RESOURCE_NAME),
+                    unstream(cache_path),
+                    # load(datapackage_path, resources=RESOURCE_NAME),
                 )
 
 
